==> zscaler_sdk_python-1.7.3.tar.gz: zscaler_sdk_python-1.7.3/zscaler/zidentity/zidentity_service.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from zscaler.request_executor import RequestExecutor
from zscaler.zidentity.api_client import APIClientAPI
from zscaler.zidentity.user_entitlement import EntitlementAPI
from zscaler.zidentity.groups import GroupsAPI
from zscaler.zidentity.users import UsersAPI
from zscaler.zidentity.resource_servers import ResourceServersAPI


class ZIdentityService:
    """Zidentity Service client, exposing various Zidentity APIs."""

    def __init__(self, request_executor: RequestExecutor):
        # Ensure the service gets the request executor from the Client object
        self._request_executor = request_executor

    @property
    def api_client(self):
        """
        The interface object for the :ref:`Zidentity API Client interface <zidentity-api_client>`.

        """
        return APIClientAPI(self._request_executor)

    @property
    def groups(self):
        """
        The interface object for the :ref:`Zidentity Groups interface <zidentity-groups>`.

        """
        return GroupsAPI(self._request_executor)

    @property
    def users(self):
        """
        The interface object for the :ref:`Zidentity Users interface <zidentity-users>`.

        """
        return UsersAPI(self._request_executor)

    @property
    def user_entitlement(self):
        """
        The interface object for the :ref:`Zidentity Entitlement interface <zidentity-user_entitlement>`.

        """
        return EntitlementAPI(self._request_executor)

    @property
    def resource_servers(self):
        """
        The interface object for the :ref:`Zidentity Resource Servers interface <zidentity-resource_servers>`.

        """
        return ResourceServersAPI(self._request_executor)

==> zscaler_sdk_python-1.9.2.tar.gz: zscaler_sdk_python-1.9.2/zscaler/zidentity/zidentity_service.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from typing import Dict, Any
from zscaler.request_executor import RequestExecutor
from zscaler.zidentity.api_client import APIClientAPI
from zscaler.zidentity.user_entitlement import EntitlementAPI
from zscaler.zidentity.groups import GroupsAPI
from zscaler.zidentity.users import UsersAPI
from zscaler.zidentity.resource_servers import ResourceServersAPI


class ZIdentityService:
    """Zidentity Service client, exposing various Zidentity APIs."""

    def __init__(self, request_executor: RequestExecutor):
        # Ensure the service gets the request executor from the Client object
        self._request_executor = request_executor

    @property
    def api_client(self) -> APIClientAPI:
        """
        The interface object for the :ref:`Zidentity API Client interface <zidentity-api_client>`.

        """
        return APIClientAPI(self._request_executor)

    @property
    def groups(self) -> GroupsAPI:
        """
        The interface object for the :ref:`Zidentity Groups interface <zidentity-groups>`.

        """
        return GroupsAPI(self._request_executor)

    @property
    def users(self) -> UsersAPI:
        """
        The interface object for the :ref:`Zidentity Users interface <zidentity-users>`.

        """
        return UsersAPI(self._request_executor)

    @property
    def user_entitlement(self) -> EntitlementAPI:
        """
        The interface object for the :ref:`Zidentity Entitlement interface <zidentity-user_entitlement>`.

        """
        return EntitlementAPI(self._request_executor)

    @property
    def resource_servers(self) -> ResourceServersAPI:
        """
        The interface object for the :ref:`Zidentity Resource Servers interface <zidentity-resource_servers>`.

        """
        return ResourceServersAPI(self._request_executor)
